@@ -1,4 +1,4 @@
-context("nhd_get")
+context("get")
 
 test_that("nhd_get fails well", {
   expect_error(nhd_get(state = "gibberish"),
@@ -15,12 +15,15 @@ test_that("remote urls are constructed correctly", {
   skip_on_cran()
   skip_on_travis()
 
-  expect_true(RCurl::url.exists(
-    get_plus_remotepath(4, component = "NHDSnapshot")))
+  expect_true(
+    RCurl::url.exists(
+      nhdR:::get_plus_remotepath(4, component = "NHDSnapshot"))
+    )
 
-  expect_true(RCurl::url.exists(
-    get_plus_remotepath("National", component = "V1_To_V2_Crosswalk")
-  ))
+  expect_true(
+    RCurl::url.exists(
+      nhdR:::get_plus_remotepath("National", component = "V1_To_V2_Crosswalk"))
+    )
 
 
 })
